@@ -49,10 +49,10 @@ void halevt_device_added(LibHalContext *ctx, const char *udi)
 {
     halevt_insertion *current_insertion = halevt_insertion_root;
 
-/*
-    DEBUG("New Device: %s", udi);
-*/
-    DEBUG("New Device: %s", udi);
+    if (halevt_report)
+    {
+        DEBUG("New Device: %s", udi);
+    }
     while (current_insertion != NULL)
     {
         if (halevt_true_tree(current_insertion->match, udi, NULL))
@@ -77,7 +77,10 @@ void halevt_device_removed(LibHalContext *ctx, const char *udi)
 /*
     DEBUG("Device removed: %s", udi);
 */
-    DEBUG("Device removed: %s", udi);
+    if (halevt_report)
+    {
+        DEBUG("Device removed: %s", udi);
+    }
 
     /* use preferably the device from the devices list since the 
      * properties will be right */
@@ -118,7 +121,10 @@ void halevt_device_removed(LibHalContext *ctx, const char *udi)
 void halevt_device_new_capability(LibHalContext *ctx, const char *udi,
                         const char *capability)
 {
-    DEBUG("Capability new %s:%s",udi,capability);
+    if (halevt_report)
+    {
+        DEBUG("Capability new %s:%s",udi,capability);
+    }
 }
 
 /** Invoked when device in the Global Device List loses a capability.
@@ -129,7 +135,10 @@ void halevt_device_new_capability(LibHalContext *ctx, const char *udi,
 void halevt_device_lost_capability (LibHalContext *ctx, const char *udi,
                            const char *capability)
 {
-    DEBUG("Capability lost %s:%s",udi,capability);
+    if (halevt_report)
+    {
+        DEBUG("Capability lost %s:%s",udi,capability);
+    }
 }
 
 /** Invoked when a property of a device in the Global Device List is
@@ -141,7 +150,10 @@ void halevt_device_lost_capability (LibHalContext *ctx, const char *udi,
 void halevt_device_property_modified(LibHalContext *ctx, const char *udi,
   const char *key, dbus_bool_t is_removed, dbus_bool_t is_added)
 {
-    DEBUG("Property %s:%s modified",udi,key);
+    if (halevt_report)
+    {
+        DEBUG("Property %s:%s modified (removed: %d, added: %d)",udi,key,is_removed,is_added);
+    }
 
     halevt_property *current_property = halevt_property_root; 
     halevt_property_action *current_action;
@@ -183,7 +195,10 @@ void halevt_device_property_modified(LibHalContext *ctx, const char *udi,
 void halevt_device_condition(LibHalContext *ctx, const char *udi,
     const char *condition_name, const char *condition_detail)
 {
-    DEBUG("Condition: %s,%s", udi,condition_name);
+    if (halevt_report)
+    {
+        DEBUG("Condition: %s,%s (%s)", udi,condition_name,condition_detail);
+    }
 
     halevt_condition *current_condition = halevt_condition_root;
     while (current_condition != NULL)
@@ -541,6 +556,11 @@ char **halevt_udi_property_value (const char *property, const char *udi)
     return values;
 }
 
+/*
+ * return the value for a property. If the property is 'udi' simply
+ * return the udi. Otherwise if a device is given look at the device
+ * property, otherwise use hal to get the property.
+ */
 char **halevt_property_value(const char *key, const char *udi,
    const halevt_device* device)
 {
