@@ -207,7 +207,8 @@ void usage()
    -g x             run as group <x>\n\
    -p x             use pid file <x> instead of the default\n\
                     '-' means not to use any pid file\n\
-   -u x             run as user <x>\n"
+   -u x             run as user <x>\n\n\
+   -i               report events, no configuration read, stay in foreground\n"
 ));
 }
 
